@@ -1,11 +1,12 @@
 package List::Objects::WithUtils::Role::Hash;
 {
-  $List::Objects::WithUtils::Role::Hash::VERSION = '2.005001';
+  $List::Objects::WithUtils::Role::Hash::VERSION = '2.006001';
 }
 use strictures 1;
 
 use Module::Runtime ();
 use Scalar::Util ();
+use List::MoreUtils ();
 
 =pod
 
@@ -116,7 +117,17 @@ sub values {
 sub intersection {
   my %seen;
   blessed_or_pkg($_[0])->array_type->new(
-    grep {; ++$seen{$_} > $#_ } map {; CORE::keys %$_ } @_
+    List::MoreUtils::uniq
+      grep {; ++$seen{$_} > $#_ } map {; CORE::keys %$_ } @_
+  )
+}
+
+sub diff {
+  my %seen;
+  my @vals = map {; CORE::keys %$_ } @_;
+  $seen{$_}++ for @vals;
+  blessed_or_pkg($_[0])->array_type->new(
+    grep {; $seen{$_} != @_ } List::MoreUtils::uniq @vals
   )
 }
 
@@ -281,6 +292,12 @@ for modification:
 Returns the list of keys common between all given hash-type objects (including
 the invocant) as an L</array_type> object.
 
+=head2 diff
+
+The opposite of L</intersection>; returns the list of keys that are not common
+to all given hash-type objects (including the invocant) as an L</array_type>
+object.
+
 =head2 is_empty
 
 Returns boolean true if the hash has no keys.
